@@ -22,25 +22,6 @@ function deploy {
     tools/kolla-ansible -i ${RAW_INVENTORY} -vvv deploy &> /tmp/logs/ansible/deploy
     tools/kolla-ansible -i ${RAW_INVENTORY} -vvv post-deploy &> /tmp/logs/ansible/post-deploy
     tools/kolla-ansible -i ${RAW_INVENTORY} -vvv check &> /tmp/logs/ansible/check-deploy
-
-    if [[ ${ACTION} != "mariadb" ]]; then
-        init_runonce
-    fi
-}
-
-function init_runonce {
-    . /etc/kolla/admin-openrc.sh
-    . ~/openstackclient-venv/bin/activate
-
-    # Wait for service ready
-    sleep 15
-
-    if ! openstack image show cirros >/dev/null 2>&1; then
-        echo "Initialising OpenStack resources via init-runonce"
-        tools/init-runonce &> /tmp/logs/ansible/init-runonce
-    else
-        echo "Not running init-runonce - resources exist"
-    fi
 }
 
 
