@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# FIXME(yoctozepto): tests do not imitate how ansible would handle module args
+
 import copy
 import imp
 import os
@@ -42,12 +44,21 @@ class ModuleArgsTest(base.BaseTestCase):
             common_options=dict(required=False, type='dict', default=dict()),
             action=dict(
                 required=True, type='str',
-                choices=['compare_container', 'compare_image', 'create_volume',
-                         'get_container_env', 'get_container_state',
-                         'pull_image', 'recreate_or_restart_container',
-                         'remove_container', 'remove_image', 'remove_volume',
-                         'restart_container', 'start_container',
-                         'stop_container']),
+                choices=['compare_container',
+                         'compare_image',
+                         'create_volume',
+                         'ensure_image',
+                         'get_container_env',
+                         'get_container_state',
+                         'pull_image',
+                         'recreate_or_restart_container',
+                         'remove_container',
+                         'remove_image',
+                         'remove_volume',
+                         'restart_container',
+                         'start_container',
+                         'stop_container',
+                         'stop_and_remove_container']),
             api_version=dict(required=False, type='str', default='auto'),
             auth_email=dict(required=False, type='str'),
             auth_password=dict(required=False, type='str', no_log=True),
@@ -71,7 +82,6 @@ class ModuleArgsTest(base.BaseTestCase):
             remove_on_exit=dict(required=False, type='bool', default=True),
             restart_policy=dict(
                 required=False, type='str', choices=['no',
-                                                     'never',
                                                      'on-failure',
                                                      'always',
                                                      'unless-stopped']),
@@ -88,7 +98,6 @@ class ModuleArgsTest(base.BaseTestCase):
             volumes_from=dict(required=False, type='list'),
             dimensions=dict(required=False, type='dict', default=dict()),
             tty=dict(required=False, type='bool', default=False),
-            client_timeout=dict(required=False, type='int', default=120),
             )
         required_if = [
             ['action', 'pull_image', ['image']],
@@ -96,6 +105,7 @@ class ModuleArgsTest(base.BaseTestCase):
             ['action', 'compare_container', ['name']],
             ['action', 'compare_image', ['name']],
             ['action', 'create_volume', ['name']],
+            ['action', 'ensure_image', ['image']],
             ['action', 'get_container_env', ['name']],
             ['action', 'get_container_state', ['name']],
             ['action', 'recreate_or_restart_container', ['name']],
@@ -103,7 +113,8 @@ class ModuleArgsTest(base.BaseTestCase):
             ['action', 'remove_image', ['image']],
             ['action', 'remove_volume', ['name']],
             ['action', 'restart_container', ['name']],
-            ['action', 'stop_container', ['name']]
+            ['action', 'stop_container', ['name']],
+            ['action', 'stop_and_remove_container', ['name']],
         ]
 
         kd.AnsibleModule = mock.MagicMock()
@@ -386,6 +397,29 @@ class TestContainer(base.BaseTestCase):
         self.dw.module.fail_json.assert_called_once_with(
             msg="No such container: fake_container to stop")
 
+    def test_stop_and_remove_container(self):
+        self.dw = get_DockerWorker({'name': 'my_container',
+                                    'action': 'stop_and_remove_container'})
+        self.dw.dc.containers.return_value = self.fake_data['containers']
+        self.dw.stop_and_remove_container()
+
+        self.assertTrue(self.dw.changed)
+        self.dw.dc.containers.assert_called_with(all=True)
+        self.dw.dc.stop.assert_called_once_with('my_container', timeout=10)
+        self.dw.dc.remove_container.assert_called_once_with(
+            container='my_container', force=True)
+
+    def test_stop_and_remove_container_not_exists(self):
+        self.dw = get_DockerWorker({'name': 'fake_container',
+                                    'action': 'stop_and_remove_container'})
+        self.dw.dc.containers.return_value = self.fake_data['containers']
+        self.dw.stop_and_remove_container()
+
+        self.assertFalse(self.dw.changed)
+        self.dw.dc.containers.assert_called_with(all=True)
+        self.assertFalse(self.dw.dc.stop.called)
+        self.assertFalse(self.dw.dc.remove_container.called)
+
     def test_restart_container(self):
         self.dw = get_DockerWorker({'name': 'my_container',
                                     'action': 'restart_container'})
